import datetime
import time
from urllib.parse import urlparse
import logging
import threading
import ujson

import grpc
from grpc._cython import cygrpc

from ..grpc_gen import milvus_pb2_grpc
from ..grpc_gen import milvus_pb2 as grpc_types
from ..grpc_gen import service_pb2_grpc
from ..grpc_gen import service_pb2 as service_types
from ..grpc_gen import service_pb2_grpc
from ..grpc_gen import service_msg_pb2 as service_msg_types
from .abstract import QueryResult, CollectionSchema
from .prepare import Prepare
from .types import Status
from .check import (
    int_or_str,
    is_legal_host,
    is_legal_port,
)

from .abs_client import AbsMilvus
from .asynch import SearchFuture, InsertFuture, CreateIndexFuture, CompactFuture, FlushFuture

from .hooks import BaseSearchHook
from .client_hooks import SearchHook, HybridSearchHook
from .exceptions import *
from ..settings import DefaultConfig as config
from . import __version__

LOGGER = logging.getLogger(__name__)


def error_handler(*rargs):
    def wrapper(func):
        def handler(self, *args, **kwargs):
            record_dict = {}
            try:
                record_dict["API start"] = str(datetime.datetime.now())
                if self._pre_ping:
                    self.ping()
                record_dict["RPC start"] = str(datetime.datetime.now())
                return func(self, *args, **kwargs)
            except BaseException as e:
                LOGGER.error("Error: {}".format(e))
                if e.code == Status.ILLEGAL_COLLECTION_NAME:
                    raise IllegalCollectionNameException(e.code, e.message)
                if e.code == Status.COLLECTION_NOT_EXISTS:
                    raise CollectionNotExistException(e.code, e.message)

                raise e

            except grpc.FutureTimeoutError as e:
                record_dict["RPC timeout"] = str(datetime.datetime.now())
                LOGGER.error("\nAddr [{}] {}\nRequest timeout: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
                raise e
            except grpc.RpcError as e:
                record_dict["RPC error"] = str(datetime.datetime.now())
                LOGGER.error("\nAddr [{}] {}\nRPC error: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
                raise e
            except Exception as e:
                record_dict["Exception"] = str(datetime.datetime.now())
                LOGGER.error("\nAddr [{}] {}\nExcepted error: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
                raise e

        return handler

    return wrapper


def set_uri(host, port, uri):
    if host is not None:
        _port = port if port is not None else config.GRPC_PORT
        _host = host
    elif port is None:
        try:
            _uri = urlparse(uri) if uri else urlparse(config.GRPC_URI)
            _host = _uri.hostname
            _port = _uri.port
        except (AttributeError, ValueError, TypeError) as e:
            raise ParamError("uri is illegal: {}".format(e))
    else:
        raise ParamError("Param is not complete. Please invoke as follow:\n"
                         "\t(host = ${HOST}, port = ${PORT})\n"
                         "\t(uri = ${URI})\n")

    if not is_legal_host(_host) or not is_legal_port(_port):
        raise ParamError("host or port is illeagl")

    return "{}:{}".format(str(_host), str(_port))


class GrpcHandler(AbsMilvus):
    def __init__(self, host=None, port=None, pre_ping=True, **kwargs):
        self._channel = None
        self._stub = None
        self._uri = None
        self.status = None
        self._connected = False
        self._pre_ping = pre_ping
        # if self._pre_ping:
        self._max_retry = kwargs.get("max_retry", 5)

        # record
        self._id = kwargs.get("conn_id", 0)

        # condition
        self._condition = threading.Condition()
        self._request_id = 0

        # client hook
        self._search_hook = SearchHook()
        self._hybrid_search_hook = HybridSearchHook()
        self._search_file_hook = SearchHook()

        # set server uri if object is initialized with parameter
        _uri = kwargs.get("uri", None)
        self._setup(host, port, _uri, pre_ping)

    def __str__(self):
        attr_list = ['%s=%r' % (key, value)
                     for key, value in self.__dict__.items() if not key.startswith('_')]
        return '<Milvus: {}>'.format(', '.join(attr_list))

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        pass

    def _setup(self, host, port, uri, pre_ping=False):
        """
        Create a grpc channel and a stub

        :raises: NotConnectError

        """
        self._uri = set_uri(host, port, uri)
        self._channel = grpc.insecure_channel(
            self._uri,
            options=[(cygrpc.ChannelArgKey.max_send_message_length, -1),
                     (cygrpc.ChannelArgKey.max_receive_message_length, -1),
                     ('grpc.enable_retries', 1),
                     ('grpc.keepalive_time_ms', 55000)]
        )
        # self._stub = milvus_pb2_grpc.MilvusServiceStub(self._channel)
        self._stub = service_pb2_grpc.MilvusServiceStub(self._channel)
        self.status = Status()

    def _pre_request(self):
        if self._pre_ping:
            self.ping()

    def _get_request_id(self):
        with self._condition:
            _id = self._request_id
            self._request_id += 1
            return _id

    def set_hook(self, **kwargs):
        """
        specify client hooks.
        The client hooks are used in methods which interact with server.
        Use key-value method to set hooks. Supported hook setting currently is as follow.

            search hook,
            search-in-file hook

        """

        # config search hook
        _search_hook = kwargs.get('search', None)
        if _search_hook:
            if not isinstance(_search_hook, BaseSearchHook):
                raise ParamError("search hook must be a subclass of `BaseSearchHook`")

            self._search_hook = _search_hook

        _search_file_hook = kwargs.get('search_in_file', None)
        if _search_file_hook:
            if not isinstance(_search_file_hook, BaseSearchHook):
                raise ParamError("search hook must be a subclass of `BaseSearchHook`")

            self._search_file_hook = _search_file_hook

    def ping(self):
        begin_timeout = 1
        timeout = begin_timeout
        ft = grpc.channel_ready_future(self._channel)
        retry = self._max_retry
        try:
            while retry > 0:
                try:
                    ft.result(timeout=timeout)
                    return True
                except:
                    retry -= 1
                    LOGGER.debug("Retry connect addr <{}> {} times".format(self._uri, self._max_retry - retry))
                    if retry > 0:
                        timeout *= 2
                        continue
                    else:
                        LOGGER.error("Retry to connect server {} failed.".format(self._uri))
                        raise
        except grpc.FutureTimeoutError:
            raise NotConnectError('Fail connecting to server on {}. Timeout'.format(self._uri))
        except grpc.RpcError as e:
            raise NotConnectError("Connect error: <{}>".format(e))
        # Unexpected error
        except Exception as e:
            raise NotConnectError("Error occurred when trying to connect server:\n"
                                  "\t<{}>".format(str(e)))

    @property
    def server_address(self):
        """
        Server network address
        """
        return self._uri

    @error_handler()
    def create_collection(self, collection_name, fields, timeout=30):
        collection_schema = Prepare.collection_schema(collection_name, fields)

        rf = self._stub.CreateCollection.future(collection_schema, wait_for_ready=True, timeout=timeout)
        status = rf.result()
        if status.error_code != 0:
            LOGGER.error(status)
            raise BaseException(status.error_code, status.reason)

        # return Status(status.error_code, status.reason)

    @error_handler()
    def drop_collection(self, collection_name, timeout=20):
        collection_name = Prepare.collection_name(collection_name)

        rf = self._stub.DropCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
        status = rf.result()
        if status.error_code != 0:
            raise BaseException(status.error_code, status.reason)

        # return Status(status.error_code, status.reason)

    @error_handler(False)
    def has_collection(self, collection_name, timeout=30, **kwargs):
        collection_name = Prepare.collection_name(collection_name)

        rf = self._stub.HasCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
        reply = rf.result()
        if reply.status.error_code == 0:
            # return Status(reply.status.error_code, reply.status.reason), reply.value
            return reply.value

        raise BaseException(reply.status.error_code, reply.status.reason)

    @error_handler(None)
    def get_collection_info(self, collection_name, timeout=30, **kwargs):
        collection_name = Prepare.collection_name(collection_name)
        rf = self._stub.DescribeCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        status = response.status

        if response.status.error_code == 0:
            # return Status(status.error_code, status.reason), CollectionSchema(raw=response).dict()
            return CollectionSchema(raw=response).dict()

        LOGGER.error(response.status)
        raise BaseException(response.status.error_code, response.status.reason)
        # return Status(status.error_code, status.reason), CollectionSchema(None)

    @error_handler([])
    def list_collections(self, timeout=30):
        empty = Prepare.empty()
        rf = self._stub.ShowCollections.future(empty, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        status = response.status
        if response.status.error_code == 0:
            # return Status(status.error_code, status.reason), [name for name in response.values if len(name) > 0]
            return [name for name in response.values if len(name) > 0]
        raise BaseException(status.error_code, status.reason)

    @error_handler()
    def create_partition(self, collection_name, partition_tag, timeout=30):
        request = Prepare.partition_name(collection_name, partition_tag)
        rf = self._stub.CreatePartition.future(request, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        if response.error_code != 0:
            raise BaseException(response.error_code, response.reason)
        # return Status(response.status.error_code, response.status.reason)

    @error_handler()
    def drop_partition(self, collection_name, partition_tag, timeout=30):
        request = Prepare.partition_name(collection_name, partition_tag)

        rf = self._stub.DropPartition.future(request, wait_for_ready=True, timeout=timeout)
        response = rf.result()

        if response.error_code != 0:
            raise BaseException(response.error_code, response.reason)

        # return Status(response.error_code, response.reason)

    @error_handler(False)
    def has_partition(self, collection_name, partition_tag, timeout=30):
        request = Prepare.partition_name(collection_name, partition_tag)
        rf = self._stub.HasPartition.future(request, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        status = response.status
        if status.error_code == 0:
            return response.value

        raise BaseException(status.error_code, status.reason)

    @error_handler(None)
    def get_partition_info(self, collection_name, partition_tag, timeout=30):
        request = Prepare.partition_name(collection_name, partition_tag)
        rf = self._stub.DescribePartition.future(request, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        status = response.status
        if status.error_code == 0:
            statistics = response.statistics
            info_dict = dict()
            for kv in statistics:
                info_dict[kv.key] = kv.value
            return info_dict
        raise BaseException(status.error_code, status.reason)

    @error_handler([])
    def list_partitions(self, collection_name, timeout=30):
        request = Prepare.collection_name(collection_name)

        rf = self._stub.ShowPartitions.future(request, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        status = response.status
        if status.error_code == 0:
            return [p for p in response.values]

        raise BaseException(status.error_code, status.reason)

    @error_handler([])
    def bulk_insert(self, collection_name, entities, ids=None, partition_tag=None, params=None, timeout=None, **kwargs):
        insert_param = kwargs.get('insert_param', None)

        # if insert_param and not isinstance(insert_param, grpc_types.InsertParam):
        #     raise ParamError("The value of key 'insert_param' is invalid")
        if insert_param and not isinstance(insert_param, service_msg_types.RowBatch):
            raise ParamError("The value of key 'insert_param' is invalid")

        collection = Prepare.collection_name(collection_name)
        rf = self._stub.DescribeCollection.future(collection, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        if response.status.error_code != 0:
            raise BaseException(response.status.error_code, response.status.reason)
        collection_schema = CollectionSchema(raw=response).dict()

        auto_id = collection_schema["auto_id"]
        fields_name = list()
        for i in range(len(entities)):
            if "name" in entities[i]:
                fields_name.append(entities[i]["name"])
        if not auto_id and ids is None and "_id" not in fields_name:
            raise ParamError("You should specify the ids of entities!")

        if not auto_id and ids is not None and "_id" in fields_name:
            raise ParamError("You should specify the ids of entities!")

        fields_info = collection_schema["fields"]

        if (auto_id and len(entities) != len(fields_info)) \
                or (not auto_id and ids is not None and len(entities) == len(fields_info)):
            raise ParamError("The length of entities must be equal to the number of fields!")

        if ids is None:
            ids = []
            for entity in entities:
                if "_id" in entity:
                    ids.append(entity["_id"])
            if not ids:
                ids = None

        body = insert_param if insert_param \
            else Prepare.bulk_insert_param(collection_name, entities, partition_tag, ids, params, fields_info, auto_id=auto_id)

        rf = self._stub.Insert.future(body, wait_for_ready=True, timeout=timeout)
        if kwargs.get("_async", False) is True:
            cb = kwargs.get("_callback", None)
            return InsertFuture(rf, cb)

        response = rf.result()
        if response.status.error_code == 0:
            if auto_id:
                return list(range(response.begin, response.end))
            return list(ids)

        raise BaseException(response.status.error_code, response.status.reason)

    @error_handler([])
    def insert(self, collection_name, entities, ids=None, partition_tag=None, params=None, timeout=None, **kwargs):
        insert_param = kwargs.get('insert_param', None)

        # if insert_param and not isinstance(insert_param, grpc_types.InsertParam):
        #     raise ParamError("The value of key 'insert_param' is invalid")
        if insert_param and not isinstance(insert_param, service_msg_types.RowBatch):
            raise ParamError("The value of key 'insert_param' is invalid")

        collection = Prepare.collection_name(collection_name)
        rf = self._stub.DescribeCollection.future(collection, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        if response.status.error_code != 0:
            raise BaseException(response.status.error_code, response.status.reason)
        collection_schema = CollectionSchema(raw=response).dict()

        auto_id = collection_schema["auto_id"]
        fields_name = list()
        entity = entities[0]
        for key, value in entity.items():
            if key in fields_name:
                raise ParamError("duplicated field name in entity")
            fields_name.append(key)

        if not auto_id and ids is None and "_id" not in fields_name:
            raise ParamError("You should specify the ids of entities!")

        if not auto_id and ids is not None and "_id" in fields_name:
            raise ParamError("You should specify the ids of entities!")

        fields_info = collection_schema["fields"]

        if (auto_id and len(entities[0]) != len(fields_info)) \
                or (not auto_id and ids is not None and len(entities[0]) == len(fields_info)):
            raise ParamError("The length of entities must be equal to the number of fields!")

        if ids is None:
            ids = []
            for entity in entities:
                if "_id" in entity:
                    ids.append(entity["_id"])
            if not ids:
                ids = None

        body = insert_param if insert_param \
            else Prepare.insert_param(collection_name, entities, partition_tag, ids, params, fields_info, auto_id=auto_id)

        rf = self._stub.Insert.future(body, wait_for_ready=True, timeout=timeout)
        if kwargs.get("_async", False) is True:
            cb = kwargs.get("_callback", None)
            return InsertFuture(rf, cb)

        response = rf.result()
        if response.status.error_code == 0:
            if auto_id:
                return list(range(response.begin, response.end))
            return list(ids)

        raise BaseException(response.status.error_code, response.status.reason)

    @error_handler(None)
    def search(self, collection_name, query_entities, partition_tags=None, fields=None, **kwargs):
        to = kwargs.get("timeout", None)
        rf = self._stub.HasCollection.future(Prepare.collection_name(collection_name), wait_for_ready=True, timeout=to)
        reply = rf.result()
        if reply.status.error_code != 0 or not reply.value:
            raise BaseException(reply.status.error_code, "collection not exists")

        request = Prepare.search_param(collection_name, query_entities, partition_tags, fields)
        self._search_hook.pre_search()
        ft = self._stub.Search.future(request, wait_for_ready=True, timeout=to)
        if kwargs.get("_async", False) is True:
            func = kwargs.get("_callback", None)
            return SearchFuture(ft, func)

        response = ft.result()
        self._search_hook.aft_search()

        if self._search_hook.on_response():
            return response

        if response.status.error_code != 0:
            raise BaseException(response.status.error_code, response.status.reason)

        collection_schema = self.get_collection_info(collection_name=collection_name)
        auto_id = collection_schema["auto_id"]

        # TODO: handler response
        # resutls = self._search_hook.handle_response(response)

        return QueryResult(response, auto_id)

    @error_handler()
    def create_index(self, collection_name, field_name, params, timeout=None, **kwargs):
        index_param = Prepare.index_param(collection_name, field_name, params)
        future = self._stub.CreateIndex.future(index_param, wait_for_ready=True, timeout=timeout)
        if kwargs.get('_async', False):
            cb = kwargs.get("_callback", None)
            return CreateIndexFuture(future, cb)
        status = future.result()

        if status.error_code != 0:
            raise BaseException(status.error_code, status.reason)
        sync = kwargs.get("sync", True)
        if sync:
            self.wait_index_building_success(collection_name=collection_name, field_name= field_name)
        return Status(status.error_code, status.reason)

    @error_handler(None)
    def get_index_info(self, collection_name, field_name, timeout=None, **kwargs):
        request = Prepare.describe_index_request(collection_name, field_name)

        rf = self._stub.DescribeIndex.future(request, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        status = response.status
        if status.error_code == 0:
            extra_params = response.extra_params
            info_dict = dict()
            for kv in extra_params:
                info_dict[kv.key] = kv.value
            return info_dict
        raise BaseException(status.error_code, status.reason)

    @error_handler(False)
    def get_index_progress(self, collection_name, field_name, timeout=None, **kwargs):
        request = Prepare.describe_index_progress_request(collection_name, field_name)

        rf = self._stub.DescribeIndexProgress.future(request, wait_for_ready=True, timeout=timeout)
        response = rf.result()
        status = response.status
        if status.error_code == 0:
            return response.value
        raise BaseException(status.error_code, status.reason)

    @error_handler()
    def wait_index_building_success(self, collection_name, field_name, timeout=30, **kwargs):
        while True:
            time.sleep(0.5)
            print("\n***********  waiting for building index ***********\n")
            if self.get_index_progress(collection_name=collection_name, field_name=field_name):
                break

        return



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import common_pb2 as common__pb2
from . import schema_pb2 as schema__pb2
from . import service_msg_pb2 as service__msg__pb2


class MilvusServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateCollection = channel.unary_unary(
        '/milvus.proto.service.MilvusService/CreateCollection',
        request_serializer=schema__pb2.CollectionSchema.SerializeToString,
        response_deserializer=common__pb2.Status.FromString,
        )
    self.DropCollection = channel.unary_unary(
        '/milvus.proto.service.MilvusService/DropCollection',
        request_serializer=service__msg__pb2.CollectionName.SerializeToString,
        response_deserializer=common__pb2.Status.FromString,
        )
    self.HasCollection = channel.unary_unary(
        '/milvus.proto.service.MilvusService/HasCollection',
        request_serializer=service__msg__pb2.CollectionName.SerializeToString,
        response_deserializer=service__msg__pb2.BoolResponse.FromString,
        )
    self.DescribeCollection = channel.unary_unary(
        '/milvus.proto.service.MilvusService/DescribeCollection',
        request_serializer=service__msg__pb2.CollectionName.SerializeToString,
        response_deserializer=service__msg__pb2.CollectionDescription.FromString,
        )
    self.ShowCollections = channel.unary_unary(
        '/milvus.proto.service.MilvusService/ShowCollections',
        request_serializer=common__pb2.Empty.SerializeToString,
        response_deserializer=service__msg__pb2.StringListResponse.FromString,
        )
    self.CreatePartition = channel.unary_unary(
        '/milvus.proto.service.MilvusService/CreatePartition',
        request_serializer=service__msg__pb2.PartitionName.SerializeToString,
        response_deserializer=common__pb2.Status.FromString,
        )
    self.DropPartition = channel.unary_unary(
        '/milvus.proto.service.MilvusService/DropPartition',
        request_serializer=service__msg__pb2.PartitionName.SerializeToString,
        response_deserializer=common__pb2.Status.FromString,
        )
    self.HasPartition = channel.unary_unary(
        '/milvus.proto.service.MilvusService/HasPartition',
        request_serializer=service__msg__pb2.PartitionName.SerializeToString,
        response_deserializer=service__msg__pb2.BoolResponse.FromString,
        )
    self.DescribePartition = channel.unary_unary(
        '/milvus.proto.service.MilvusService/DescribePartition',
        request_serializer=service__msg__pb2.PartitionName.SerializeToString,
        response_deserializer=service__msg__pb2.PartitionDescription.FromString,
        )
    self.ShowPartitions = channel.unary_unary(
        '/milvus.proto.service.MilvusService/ShowPartitions',
        request_serializer=service__msg__pb2.CollectionName.SerializeToString,
        response_deserializer=service__msg__pb2.StringListResponse.FromString,
        )
    self.Insert = channel.unary_unary(
        '/milvus.proto.service.MilvusService/Insert',
        request_serializer=service__msg__pb2.RowBatch.SerializeToString,
        response_deserializer=service__msg__pb2.IntegerRangeResponse.FromString,
        )
    self.Search = channel.unary_unary(
        '/milvus.proto.service.MilvusService/Search',
        request_serializer=service__msg__pb2.Query.SerializeToString,
        response_deserializer=service__msg__pb2.QueryResult.FromString,
        )
    self.CreateIndex = channel.unary_unary(
        '/milvus.proto.service.MilvusService/CreateIndex',
        request_serializer=service__msg__pb2.IndexParam.SerializeToString,
        response_deserializer=common__pb2.Status.FromString,
        )
    self.DescribeIndex = channel.unary_unary(
        '/milvus.proto.service.MilvusService/DescribeIndex',
        request_serializer=service__msg__pb2.DescribeIndexRequest.SerializeToString,
        response_deserializer=service__msg__pb2.DescribeIndexResponse.FromString,
        )
    self.DescribeIndexProgress = channel.unary_unary(
        '/milvus.proto.service.MilvusService/DescribeIndexProgress',
        request_serializer=service__msg__pb2.DescribeIndexProgressRequest.SerializeToString,
        response_deserializer=service__msg__pb2.BoolResponse.FromString,
        )


class MilvusServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateCollection(self, request, context):
    """*
    @brief This method is used to create collection

    @param CollectionSchema, use to provide collection information to be created.

    @return Status
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DropCollection(self, request, context):
    """*
    @brief This method is used to delete collection.

    @param CollectionName, collection name is going to be deleted.

    @return Status
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HasCollection(self, request, context):
    """*
    @brief This method is used to test collection existence.

    @param CollectionName, collection name is going to be tested.

    @return BoolResponse
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DescribeCollection(self, request, context):
    """*
    @brief This method is used to get collection schema.

    @param CollectionName, target collection name.

    @return CollectionDescription
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ShowCollections(self, request, context):
    """*
    @brief This method is used to list all collections.

    @return CollectionNameList
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreatePartition(self, request, context):
    """*
    @brief This method is used to create partition

    @return Status
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DropPartition(self, request, context):
    """*
    @brief This method is used to drop partition

    @return Status
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HasPartition(self, request, context):
    """*
    @brief This method is used to test partition existence.

    @return BoolResponse
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DescribePartition(self, request, context):
    """*
    @brief This method is used to get basic partition infomation.

    @return PartitionDescription
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ShowPartitions(self, request, context):
    """*
    @brief This method is used to show partition information

    @param CollectionName, target collection name.

    @return StringListResponse
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Insert(self, request, context):
    """*
    @brief This method is used to add vector array to collection.

    @param RowBatch, insert rows.

    @return IntegerRangeResponse contains id of the inserted rows.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Search(self, request, context):
    """*
    @brief This method is used to query vector in collection.

    @param Query.

    @return QueryResult
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateIndex(self, request, context):
    """*
    @brief This method is used to build index by collection in sync mode.

    @param IndexParam, index paramters.

    @return Status
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DescribeIndex(self, request, context):
    """*
    @brief This method is used to describe index

    @param IndexParam, target index.

    @return IndexParam
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DescribeIndexProgress(self, request, context):
    """*
    @brief This method is used to query index building progress

    @param IndexParam, target index.

    @return IndexParam
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MilvusServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateCollection': grpc.unary_unary_rpc_method_handler(
          servicer.CreateCollection,
          request_deserializer=schema__pb2.CollectionSchema.FromString,
          response_serializer=common__pb2.Status.SerializeToString,
      ),
      'DropCollection': grpc.unary_unary_rpc_method_handler(
          servicer.DropCollection,
          request_deserializer=service__msg__pb2.CollectionName.FromString,
          response_serializer=common__pb2.Status.SerializeToString,
      ),
      'HasCollection': grpc.unary_unary_rpc_method_handler(
          servicer.HasCollection,
          request_deserializer=service__msg__pb2.CollectionName.FromString,
          response_serializer=service__msg__pb2.BoolResponse.SerializeToString,
      ),
      'DescribeCollection': grpc.unary_unary_rpc_method_handler(
          servicer.DescribeCollection,
          request_deserializer=service__msg__pb2.CollectionName.FromString,
          response_serializer=service__msg__pb2.CollectionDescription.SerializeToString,
      ),
      'ShowCollections': grpc.unary_unary_rpc_method_handler(
          servicer.ShowCollections,
          request_deserializer=common__pb2.Empty.FromString,
          response_serializer=service__msg__pb2.StringListResponse.SerializeToString,
      ),
      'CreatePartition': grpc.unary_unary_rpc_method_handler(
          servicer.CreatePartition,
          request_deserializer=service__msg__pb2.PartitionName.FromString,
          response_serializer=common__pb2.Status.SerializeToString,
      ),
      'DropPartition': grpc.unary_unary_rpc_method_handler(
          servicer.DropPartition,
          request_deserializer=service__msg__pb2.PartitionName.FromString,
          response_serializer=common__pb2.Status.SerializeToString,
      ),
      'HasPartition': grpc.unary_unary_rpc_method_handler(
          servicer.HasPartition,
          request_deserializer=service__msg__pb2.PartitionName.FromString,
          response_serializer=service__msg__pb2.BoolResponse.SerializeToString,
      ),
      'DescribePartition': grpc.unary_unary_rpc_method_handler(
          servicer.DescribePartition,
          request_deserializer=service__msg__pb2.PartitionName.FromString,
          response_serializer=service__msg__pb2.PartitionDescription.SerializeToString,
      ),
      'ShowPartitions': grpc.unary_unary_rpc_method_handler(
          servicer.ShowPartitions,
          request_deserializer=service__msg__pb2.CollectionName.FromString,
          response_serializer=service__msg__pb2.StringListResponse.SerializeToString,
      ),
      'Insert': grpc.unary_unary_rpc_method_handler(
          servicer.Insert,
          request_deserializer=service__msg__pb2.RowBatch.FromString,
          response_serializer=service__msg__pb2.IntegerRangeResponse.SerializeToString,
      ),
      'Search': grpc.unary_unary_rpc_method_handler(
          servicer.Search,
          request_deserializer=service__msg__pb2.Query.FromString,
          response_serializer=service__msg__pb2.QueryResult.SerializeToString,
      ),
      'CreateIndex': grpc.unary_unary_rpc_method_handler(
          servicer.CreateIndex,
          request_deserializer=service__msg__pb2.IndexParam.FromString,
          response_serializer=common__pb2.Status.SerializeToString,
      ),
      'DescribeIndex': grpc.unary_unary_rpc_method_handler(
          servicer.DescribeIndex,
          request_deserializer=service__msg__pb2.DescribeIndexRequest.FromString,
          response_serializer=service__msg__pb2.DescribeIndexResponse.SerializeToString,
      ),
      'DescribeIndexProgress': grpc.unary_unary_rpc_method_handler(
          servicer.DescribeIndexProgress,
          request_deserializer=service__msg__pb2.DescribeIndexProgressRequest.FromString,
          response_serializer=service__msg__pb2.BoolResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'milvus.proto.service.MilvusService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-

__all__ = [
    'status_pb2', 'status_pb2_grpc',
    'milvus_pb2', 'milvus_pb2_grpc',
    'common_pb2', 'common_pb2_grpc',
    'schema_pb2', 'schema_pb2_grpc',
    'service_pb2', 'service_pb2_grpc',
    'service_msg_pb2', 'service_msg_pb2_grpc',
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='common.proto',
  package='milvus.proto.common',
  syntax='proto3',
  serialized_options=_b('Z@github.com/zilliztech/milvus-distributed/internal/proto/commonpb'),
  serialized_pb=_b('\n\x0c\x63ommon.proto\x12\x13milvus.proto.common\"\x07\n\x05\x45mpty\"L\n\x06Status\x12\x32\n\nerror_code\x18\x01 \x01(\x0e\x32\x1e.milvus.proto.common.ErrorCode\x12\x0e\n\x06reason\x18\x02 \x01(\t\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x15\n\x04\x42lob\x12\r\n\x05value\x18\x01 \x01(\x0c\"#\n\x07\x41\x64\x64ress\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03*\xb8\x04\n\tErrorCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x14\n\x10UNEXPECTED_ERROR\x10\x01\x12\x12\n\x0e\x43ONNECT_FAILED\x10\x02\x12\x15\n\x11PERMISSION_DENIED\x10\x03\x12\x19\n\x15\x43OLLECTION_NOT_EXISTS\x10\x04\x12\x14\n\x10ILLEGAL_ARGUMENT\x10\x05\x12\x15\n\x11ILLEGAL_DIMENSION\x10\x07\x12\x16\n\x12ILLEGAL_INDEX_TYPE\x10\x08\x12\x1b\n\x17ILLEGAL_COLLECTION_NAME\x10\t\x12\x10\n\x0cILLEGAL_TOPK\x10\n\x12\x15\n\x11ILLEGAL_ROWRECORD\x10\x0b\x12\x15\n\x11ILLEGAL_VECTOR_ID\x10\x0c\x12\x19\n\x15ILLEGAL_SEARCH_RESULT\x10\r\x12\x12\n\x0e\x46ILE_NOT_FOUND\x10\x0e\x12\x0f\n\x0bMETA_FAILED\x10\x0f\x12\x10\n\x0c\x43\x41\x43HE_FAILED\x10\x10\x12\x18\n\x14\x43\x41NNOT_CREATE_FOLDER\x10\x11\x12\x16\n\x12\x43\x41NNOT_CREATE_FILE\x10\x12\x12\x18\n\x14\x43\x41NNOT_DELETE_FOLDER\x10\x13\x12\x16\n\x12\x43\x41NNOT_DELETE_FILE\x10\x14\x12\x15\n\x11\x42UILD_INDEX_ERROR\x10\x15\x12\x11\n\rILLEGAL_NLIST\x10\x16\x12\x17\n\x13ILLEGAL_METRIC_TYPE\x10\x17\x12\x11\n\rOUT_OF_MEMORY\x10\x18\x12\x14\n\x0f\x44\x44_REQUEST_RACE\x10\xe8\x07\x42\x42Z@github.com/zilliztech/milvus-distributed/internal/proto/commonpbb\x06proto3')
)

_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='milvus.proto.common.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEXPECTED_ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECT_FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_DENIED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLLECTION_NOT_EXISTS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_ARGUMENT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_DIMENSION', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_INDEX_TYPE', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_COLLECTION_NAME', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_TOPK', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_ROWRECORD', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_VECTOR_ID', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_SEARCH_RESULT', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE_NOT_FOUND', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='META_FAILED', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CACHE_FAILED', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_FOLDER', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_FILE', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_DELETE_FOLDER', index=18, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_DELETE_FILE', index=19, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUILD_INDEX_ERROR', index=20, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_NLIST', index=21, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_METRIC_TYPE', index=22, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_MEMORY', index=23, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DD_REQUEST_RACE', index=24, number=1000,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=229,
  serialized_end=797,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
SUCCESS = 0
UNEXPECTED_ERROR = 1
CONNECT_FAILED = 2
PERMISSION_DENIED = 3
COLLECTION_NOT_EXISTS = 4
ILLEGAL_ARGUMENT = 5
ILLEGAL_DIMENSION = 7
ILLEGAL_INDEX_TYPE = 8
ILLEGAL_COLLECTION_NAME = 9
ILLEGAL_TOPK = 10
ILLEGAL_ROWRECORD = 11
ILLEGAL_VECTOR_ID = 12
ILLEGAL_SEARCH_RESULT = 13
FILE_NOT_FOUND = 14
META_FAILED = 15
CACHE_FAILED = 16
CANNOT_CREATE_FOLDER = 17
CANNOT_CREATE_FILE = 18
CANNOT_DELETE_FOLDER = 19
CANNOT_DELETE_FILE = 20
BUILD_INDEX_ERROR = 21
ILLEGAL_NLIST = 22
ILLEGAL_METRIC_TYPE = 23
OUT_OF_MEMORY = 24
DD_REQUEST_RACE = 1000



_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='milvus.proto.common.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=44,
)


_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='milvus.proto.common.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='milvus.proto.common.Status.error_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='milvus.proto.common.Status.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=122,
)


_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='milvus.proto.common.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='milvus.proto.common.KeyValuePair.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.common.KeyValuePair.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=166,
)


_BLOB = _descriptor.Descriptor(
  name='Blob',
  full_name='milvus.proto.common.Blob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.common.Blob.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=189,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='milvus.proto.common.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='milvus.proto.common.Address.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='milvus.proto.common.Address.port', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=226,
)

_STATUS.fields_by_name['error_code'].enum_type = _ERRORCODE
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['KeyValuePair'] = _KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['Blob'] = _BLOB
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.common.Empty)
  })
_sym_db.RegisterMessage(Empty)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.common.Status)
  })
_sym_db.RegisterMessage(Status)

KeyValuePair = _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEPAIR,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.common.KeyValuePair)
  })
_sym_db.RegisterMessage(KeyValuePair)

Blob = _reflection.GeneratedProtocolMessageType('Blob', (_message.Message,), {
  'DESCRIPTOR' : _BLOB,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.common.Blob)
  })
_sym_db.RegisterMessage(Blob)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.common.Address)
  })
_sym_db.RegisterMessage(Address)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service_msg.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import schema_pb2 as schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='service_msg.proto',
  package='milvus.proto.service',
  syntax='proto3',
  serialized_options=_b('ZAgithub.com/zilliztech/milvus-distributed/internal/proto/servicepb'),
  serialized_pb=_b('\n\x11service_msg.proto\x12\x14milvus.proto.service\x1a\x0c\x63ommon.proto\x1a\x0cschema.proto\")\n\x0e\x43ollectionName\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\"5\n\rPartitionName\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"z\n\x08RowBatch\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x15\n\rpartition_tag\x18\x02 \x01(\t\x12+\n\x08row_data\x18\x03 \x03(\x0b\x32\x19.milvus.proto.common.Blob\x12\x11\n\thash_keys\x18\x04 \x03(\r\"d\n\x10PlaceholderValue\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32%.milvus.proto.service.PlaceholderType\x12\x0e\n\x06values\x18\x03 \x03(\x0c\"P\n\x10PlaceholderGroup\x12<\n\x0cplaceholders\x18\x01 \x03(\x0b\x32&.milvus.proto.service.PlaceholderValue\"`\n\x05Query\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x16\n\x0epartition_tags\x18\x02 \x03(\t\x12\x0b\n\x03\x64sl\x18\x03 \x01(\t\x12\x19\n\x11placeholder_group\x18\x04 \x01(\x0c\"L\n\x0eStringResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\t\"J\n\x0c\x42oolResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\x08\"Q\n\x12StringListResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0e\n\x06values\x18\x02 \x03(\t\"R\n\x13IntegerListResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0e\n\x06values\x18\x02 \x03(\x03\"_\n\x14IntegerRangeResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05\x62\x65gin\x18\x02 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x03\"\xb2\x01\n\x15\x43ollectionDescription\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x35\n\x06schema\x18\x02 \x01(\x0b\x32%.milvus.proto.schema.CollectionSchema\x12\x35\n\nstatistics\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\xad\x01\n\x14PartitionDescription\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x31\n\x04name\x18\x02 \x01(\x0b\x32#.milvus.proto.service.PartitionName\x12\x35\n\nstatistics\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"^\n\x11SysConfigResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"5\n\x04Hits\x12\x0b\n\x03IDs\x18\x01 \x03(\x03\x12\x10\n\x08row_data\x18\x02 \x03(\x0c\x12\x0e\n\x06scores\x18\x03 \x03(\x02\"H\n\x0bQueryResult\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0c\n\x04hits\x18\x02 \x03(\x0c\"r\n\nIndexParam\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\x12\x37\n\x0c\x65xtra_params\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"C\n\x14\x44\x65scribeIndexRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\"K\n\x1c\x44\x65scribeIndexProgressRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\"\xaa\x01\n\x15\x44\x65scribeIndexResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x12\n\nfield_name\x18\x03 \x01(\t\x12\x37\n\x0c\x65xtra_params\x18\x04 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair*@\n\x0fPlaceholderType\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rVECTOR_BINARY\x10\x64\x12\x10\n\x0cVECTOR_FLOAT\x10\x65\x42\x43ZAgithub.com/zilliztech/milvus-distributed/internal/proto/servicepbb\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,schema__pb2.DESCRIPTOR,])

_PLACEHOLDERTYPE = _descriptor.EnumDescriptor(
  name='PlaceholderType',
  full_name='milvus.proto.service.PlaceholderType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VECTOR_BINARY', index=1, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VECTOR_FLOAT', index=2, number=101,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2010,
  serialized_end=2074,
)
_sym_db.RegisterEnumDescriptor(_PLACEHOLDERTYPE)

PlaceholderType = enum_type_wrapper.EnumTypeWrapper(_PLACEHOLDERTYPE)
NONE = 0
VECTOR_BINARY = 100
VECTOR_FLOAT = 101



_COLLECTIONNAME = _descriptor.Descriptor(
  name='CollectionName',
  full_name='milvus.proto.service.CollectionName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.CollectionName.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=112,
)


_PARTITIONNAME = _descriptor.Descriptor(
  name='PartitionName',
  full_name='milvus.proto.service.PartitionName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.PartitionName.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='milvus.proto.service.PartitionName.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=167,
)


_ROWBATCH = _descriptor.Descriptor(
  name='RowBatch',
  full_name='milvus.proto.service.RowBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.RowBatch.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_tag', full_name='milvus.proto.service.RowBatch.partition_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_data', full_name='milvus.proto.service.RowBatch.row_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash_keys', full_name='milvus.proto.service.RowBatch.hash_keys', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=291,
)


_PLACEHOLDERVALUE = _descriptor.Descriptor(
  name='PlaceholderValue',
  full_name='milvus.proto.service.PlaceholderValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='milvus.proto.service.PlaceholderValue.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='milvus.proto.service.PlaceholderValue.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.service.PlaceholderValue.values', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=393,
)


_PLACEHOLDERGROUP = _descriptor.Descriptor(
  name='PlaceholderGroup',
  full_name='milvus.proto.service.PlaceholderGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placeholders', full_name='milvus.proto.service.PlaceholderGroup.placeholders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=395,
  serialized_end=475,
)


_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='milvus.proto.service.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.Query.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_tags', full_name='milvus.proto.service.Query.partition_tags', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsl', full_name='milvus.proto.service.Query.dsl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_group', full_name='milvus.proto.service.Query.placeholder_group', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=573,
)


_STRINGRESPONSE = _descriptor.Descriptor(
  name='StringResponse',
  full_name='milvus.proto.service.StringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.StringResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.service.StringResponse.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=651,
)


_BOOLRESPONSE = _descriptor.Descriptor(
  name='BoolResponse',
  full_name='milvus.proto.service.BoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.BoolResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.service.BoolResponse.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=727,
)


_STRINGLISTRESPONSE = _descriptor.Descriptor(
  name='StringListResponse',
  full_name='milvus.proto.service.StringListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.StringListResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.service.StringListResponse.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=810,
)


_INTEGERLISTRESPONSE = _descriptor.Descriptor(
  name='IntegerListResponse',
  full_name='milvus.proto.service.IntegerListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.IntegerListResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.service.IntegerListResponse.values', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=894,
)


_INTEGERRANGERESPONSE = _descriptor.Descriptor(
  name='IntegerRangeResponse',
  full_name='milvus.proto.service.IntegerRangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.IntegerRangeResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin', full_name='milvus.proto.service.IntegerRangeResponse.begin', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='milvus.proto.service.IntegerRangeResponse.end', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=991,
)


_COLLECTIONDESCRIPTION = _descriptor.Descriptor(
  name='CollectionDescription',
  full_name='milvus.proto.service.CollectionDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.CollectionDescription.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='milvus.proto.service.CollectionDescription.schema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='milvus.proto.service.CollectionDescription.statistics', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1172,
)


_PARTITIONDESCRIPTION = _descriptor.Descriptor(
  name='PartitionDescription',
  full_name='milvus.proto.service.PartitionDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.PartitionDescription.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='milvus.proto.service.PartitionDescription.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='milvus.proto.service.PartitionDescription.statistics', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1175,
  serialized_end=1348,
)


_SYSCONFIGRESPONSE = _descriptor.Descriptor(
  name='SysConfigResponse',
  full_name='milvus.proto.service.SysConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.SysConfigResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys', full_name='milvus.proto.service.SysConfigResponse.keys', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.service.SysConfigResponse.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1350,
  serialized_end=1444,
)


_HITS = _descriptor.Descriptor(
  name='Hits',
  full_name='milvus.proto.service.Hits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='IDs', full_name='milvus.proto.service.Hits.IDs', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_data', full_name='milvus.proto.service.Hits.row_data', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scores', full_name='milvus.proto.service.Hits.scores', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1499,
)


_QUERYRESULT = _descriptor.Descriptor(
  name='QueryResult',
  full_name='milvus.proto.service.QueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.QueryResult.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hits', full_name='milvus.proto.service.QueryResult.hits', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1573,
)


_INDEXPARAM = _descriptor.Descriptor(
  name='IndexParam',
  full_name='milvus.proto.service.IndexParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.IndexParam.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.service.IndexParam.field_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_params', full_name='milvus.proto.service.IndexParam.extra_params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1575,
  serialized_end=1689,
)


_DESCRIBEINDEXREQUEST = _descriptor.Descriptor(
  name='DescribeIndexRequest',
  full_name='milvus.proto.service.DescribeIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.DescribeIndexRequest.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.service.DescribeIndexRequest.field_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1691,
  serialized_end=1758,
)


_DESCRIBEINDEXPROGRESSREQUEST = _descriptor.Descriptor(
  name='DescribeIndexProgressRequest',
  full_name='milvus.proto.service.DescribeIndexProgressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.DescribeIndexProgressRequest.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.service.DescribeIndexProgressRequest.field_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1760,
  serialized_end=1835,
)


_DESCRIBEINDEXRESPONSE = _descriptor.Descriptor(
  name='DescribeIndexResponse',
  full_name='milvus.proto.service.DescribeIndexResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.DescribeIndexResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.DescribeIndexResponse.collection_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.service.DescribeIndexResponse.field_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_params', full_name='milvus.proto.service.DescribeIndexResponse.extra_params', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1838,
  serialized_end=2008,
)

_ROWBATCH.fields_by_name['row_data'].message_type = common__pb2._BLOB
_PLACEHOLDERVALUE.fields_by_name['type'].enum_type = _PLACEHOLDERTYPE
_PLACEHOLDERGROUP.fields_by_name['placeholders'].message_type = _PLACEHOLDERVALUE
_STRINGRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_BOOLRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_STRINGLISTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_INTEGERLISTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_INTEGERRANGERESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_COLLECTIONDESCRIPTION.fields_by_name['status'].message_type = common__pb2._STATUS
_COLLECTIONDESCRIPTION.fields_by_name['schema'].message_type = schema__pb2._COLLECTIONSCHEMA
_COLLECTIONDESCRIPTION.fields_by_name['statistics'].message_type = common__pb2._KEYVALUEPAIR
_PARTITIONDESCRIPTION.fields_by_name['status'].message_type = common__pb2._STATUS
_PARTITIONDESCRIPTION.fields_by_name['name'].message_type = _PARTITIONNAME
_PARTITIONDESCRIPTION.fields_by_name['statistics'].message_type = common__pb2._KEYVALUEPAIR
_SYSCONFIGRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_QUERYRESULT.fields_by_name['status'].message_type = common__pb2._STATUS
_INDEXPARAM.fields_by_name['extra_params'].message_type = common__pb2._KEYVALUEPAIR
_DESCRIBEINDEXRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBEINDEXRESPONSE.fields_by_name['extra_params'].message_type = common__pb2._KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['CollectionName'] = _COLLECTIONNAME
DESCRIPTOR.message_types_by_name['PartitionName'] = _PARTITIONNAME
DESCRIPTOR.message_types_by_name['RowBatch'] = _ROWBATCH
DESCRIPTOR.message_types_by_name['PlaceholderValue'] = _PLACEHOLDERVALUE
DESCRIPTOR.message_types_by_name['PlaceholderGroup'] = _PLACEHOLDERGROUP
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['StringResponse'] = _STRINGRESPONSE
DESCRIPTOR.message_types_by_name['BoolResponse'] = _BOOLRESPONSE
DESCRIPTOR.message_types_by_name['StringListResponse'] = _STRINGLISTRESPONSE
DESCRIPTOR.message_types_by_name['IntegerListResponse'] = _INTEGERLISTRESPONSE
DESCRIPTOR.message_types_by_name['IntegerRangeResponse'] = _INTEGERRANGERESPONSE
DESCRIPTOR.message_types_by_name['CollectionDescription'] = _COLLECTIONDESCRIPTION
DESCRIPTOR.message_types_by_name['PartitionDescription'] = _PARTITIONDESCRIPTION
DESCRIPTOR.message_types_by_name['SysConfigResponse'] = _SYSCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['Hits'] = _HITS
DESCRIPTOR.message_types_by_name['QueryResult'] = _QUERYRESULT
DESCRIPTOR.message_types_by_name['IndexParam'] = _INDEXPARAM
DESCRIPTOR.message_types_by_name['DescribeIndexRequest'] = _DESCRIBEINDEXREQUEST
DESCRIPTOR.message_types_by_name['DescribeIndexProgressRequest'] = _DESCRIBEINDEXPROGRESSREQUEST
DESCRIPTOR.message_types_by_name['DescribeIndexResponse'] = _DESCRIBEINDEXRESPONSE
DESCRIPTOR.enum_types_by_name['PlaceholderType'] = _PLACEHOLDERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CollectionName = _reflection.GeneratedProtocolMessageType('CollectionName', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONNAME,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.CollectionName)
  })
_sym_db.RegisterMessage(CollectionName)

PartitionName = _reflection.GeneratedProtocolMessageType('PartitionName', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONNAME,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.PartitionName)
  })
_sym_db.RegisterMessage(PartitionName)

RowBatch = _reflection.GeneratedProtocolMessageType('RowBatch', (_message.Message,), {
  'DESCRIPTOR' : _ROWBATCH,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.RowBatch)
  })
_sym_db.RegisterMessage(RowBatch)

PlaceholderValue = _reflection.GeneratedProtocolMessageType('PlaceholderValue', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERVALUE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.PlaceholderValue)
  })
_sym_db.RegisterMessage(PlaceholderValue)

PlaceholderGroup = _reflection.GeneratedProtocolMessageType('PlaceholderGroup', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERGROUP,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.PlaceholderGroup)
  })
_sym_db.RegisterMessage(PlaceholderGroup)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.Query)
  })
_sym_db.RegisterMessage(Query)

StringResponse = _reflection.GeneratedProtocolMessageType('StringResponse', (_message.Message,), {
  'DESCRIPTOR' : _STRINGRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.StringResponse)
  })
_sym_db.RegisterMessage(StringResponse)

BoolResponse = _reflection.GeneratedProtocolMessageType('BoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _BOOLRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.BoolResponse)
  })
_sym_db.RegisterMessage(BoolResponse)

StringListResponse = _reflection.GeneratedProtocolMessageType('StringListResponse', (_message.Message,), {
  'DESCRIPTOR' : _STRINGLISTRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.StringListResponse)
  })
_sym_db.RegisterMessage(StringListResponse)

IntegerListResponse = _reflection.GeneratedProtocolMessageType('IntegerListResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTEGERLISTRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.IntegerListResponse)
  })
_sym_db.RegisterMessage(IntegerListResponse)

IntegerRangeResponse = _reflection.GeneratedProtocolMessageType('IntegerRangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTEGERRANGERESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.IntegerRangeResponse)
  })
_sym_db.RegisterMessage(IntegerRangeResponse)

CollectionDescription = _reflection.GeneratedProtocolMessageType('CollectionDescription', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONDESCRIPTION,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.CollectionDescription)
  })
_sym_db.RegisterMessage(CollectionDescription)

PartitionDescription = _reflection.GeneratedProtocolMessageType('PartitionDescription', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONDESCRIPTION,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.PartitionDescription)
  })
_sym_db.RegisterMessage(PartitionDescription)

SysConfigResponse = _reflection.GeneratedProtocolMessageType('SysConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYSCONFIGRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.SysConfigResponse)
  })
_sym_db.RegisterMessage(SysConfigResponse)

Hits = _reflection.GeneratedProtocolMessageType('Hits', (_message.Message,), {
  'DESCRIPTOR' : _HITS,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.Hits)
  })
_sym_db.RegisterMessage(Hits)

QueryResult = _reflection.GeneratedProtocolMessageType('QueryResult', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESULT,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.QueryResult)
  })
_sym_db.RegisterMessage(QueryResult)

IndexParam = _reflection.GeneratedProtocolMessageType('IndexParam', (_message.Message,), {
  'DESCRIPTOR' : _INDEXPARAM,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.IndexParam)
  })
_sym_db.RegisterMessage(IndexParam)

DescribeIndexRequest = _reflection.GeneratedProtocolMessageType('DescribeIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXREQUEST,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.DescribeIndexRequest)
  })
_sym_db.RegisterMessage(DescribeIndexRequest)

DescribeIndexProgressRequest = _reflection.GeneratedProtocolMessageType('DescribeIndexProgressRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXPROGRESSREQUEST,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.DescribeIndexProgressRequest)
  })
_sym_db.RegisterMessage(DescribeIndexProgressRequest)

DescribeIndexResponse = _reflection.GeneratedProtocolMessageType('DescribeIndexResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.DescribeIndexResponse)
  })
_sym_db.RegisterMessage(DescribeIndexResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import service_msg_pb2 as service__msg__pb2
from . import schema_pb2 as schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='service.proto',
  package='milvus.proto.service',
  syntax='proto3',
  serialized_options=_b('ZAgithub.com/zilliztech/milvus-distributed/internal/proto/servicepb'),
  serialized_pb=_b('\n\rservice.proto\x12\x14milvus.proto.service\x1a\x0c\x63ommon.proto\x1a\x11service_msg.proto\x1a\x0cschema.proto2\x89\x0b\n\rMilvusService\x12X\n\x10\x43reateCollection\x12%.milvus.proto.schema.CollectionSchema\x1a\x1b.milvus.proto.common.Status\"\x00\x12U\n\x0e\x44ropCollection\x12$.milvus.proto.service.CollectionName\x1a\x1b.milvus.proto.common.Status\"\x00\x12[\n\rHasCollection\x12$.milvus.proto.service.CollectionName\x1a\".milvus.proto.service.BoolResponse\"\x00\x12i\n\x12\x44\x65scribeCollection\x12$.milvus.proto.service.CollectionName\x1a+.milvus.proto.service.CollectionDescription\"\x00\x12Y\n\x0fShowCollections\x12\x1a.milvus.proto.common.Empty\x1a(.milvus.proto.service.StringListResponse\"\x00\x12U\n\x0f\x43reatePartition\x12#.milvus.proto.service.PartitionName\x1a\x1b.milvus.proto.common.Status\"\x00\x12S\n\rDropPartition\x12#.milvus.proto.service.PartitionName\x1a\x1b.milvus.proto.common.Status\"\x00\x12Y\n\x0cHasPartition\x12#.milvus.proto.service.PartitionName\x1a\".milvus.proto.service.BoolResponse\"\x00\x12\x66\n\x11\x44\x65scribePartition\x12#.milvus.proto.service.PartitionName\x1a*.milvus.proto.service.PartitionDescription\"\x00\x12\x62\n\x0eShowPartitions\x12$.milvus.proto.service.CollectionName\x1a(.milvus.proto.service.StringListResponse\"\x00\x12V\n\x06Insert\x12\x1e.milvus.proto.service.RowBatch\x1a*.milvus.proto.service.IntegerRangeResponse\"\x00\x12J\n\x06Search\x12\x1b.milvus.proto.service.Query\x1a!.milvus.proto.service.QueryResult\"\x00\x12N\n\x0b\x43reateIndex\x12 .milvus.proto.service.IndexParam\x1a\x1b.milvus.proto.common.Status\"\x00\x12j\n\rDescribeIndex\x12*.milvus.proto.service.DescribeIndexRequest\x1a+.milvus.proto.service.DescribeIndexResponse\"\x00\x12q\n\x15\x44\x65scribeIndexProgress\x12\x32.milvus.proto.service.DescribeIndexProgressRequest\x1a\".milvus.proto.service.BoolResponse\"\x00\x42\x43ZAgithub.com/zilliztech/milvus-distributed/internal/proto/servicepbb\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,service__msg__pb2.DESCRIPTOR,schema__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_MILVUSSERVICE = _descriptor.ServiceDescriptor(
  name='MilvusService',
  full_name='milvus.proto.service.MilvusService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=87,
  serialized_end=1504,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateCollection',
    full_name='milvus.proto.service.MilvusService.CreateCollection',
    index=0,
    containing_service=None,
    input_type=schema__pb2._COLLECTIONSCHEMA,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DropCollection',
    full_name='milvus.proto.service.MilvusService.DropCollection',
    index=1,
    containing_service=None,
    input_type=service__msg__pb2._COLLECTIONNAME,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HasCollection',
    full_name='milvus.proto.service.MilvusService.HasCollection',
    index=2,
    containing_service=None,
    input_type=service__msg__pb2._COLLECTIONNAME,
    output_type=service__msg__pb2._BOOLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeCollection',
    full_name='milvus.proto.service.MilvusService.DescribeCollection',
    index=3,
    containing_service=None,
    input_type=service__msg__pb2._COLLECTIONNAME,
    output_type=service__msg__pb2._COLLECTIONDESCRIPTION,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ShowCollections',
    full_name='milvus.proto.service.MilvusService.ShowCollections',
    index=4,
    containing_service=None,
    input_type=common__pb2._EMPTY,
    output_type=service__msg__pb2._STRINGLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePartition',
    full_name='milvus.proto.service.MilvusService.CreatePartition',
    index=5,
    containing_service=None,
    input_type=service__msg__pb2._PARTITIONNAME,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DropPartition',
    full_name='milvus.proto.service.MilvusService.DropPartition',
    index=6,
    containing_service=None,
    input_type=service__msg__pb2._PARTITIONNAME,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HasPartition',
    full_name='milvus.proto.service.MilvusService.HasPartition',
    index=7,
    containing_service=None,
    input_type=service__msg__pb2._PARTITIONNAME,
    output_type=service__msg__pb2._BOOLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DescribePartition',
    full_name='milvus.proto.service.MilvusService.DescribePartition',
    index=8,
    containing_service=None,
    input_type=service__msg__pb2._PARTITIONNAME,
    output_type=service__msg__pb2._PARTITIONDESCRIPTION,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ShowPartitions',
    full_name='milvus.proto.service.MilvusService.ShowPartitions',
    index=9,
    containing_service=None,
    input_type=service__msg__pb2._COLLECTIONNAME,
    output_type=service__msg__pb2._STRINGLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Insert',
    full_name='milvus.proto.service.MilvusService.Insert',
    index=10,
    containing_service=None,
    input_type=service__msg__pb2._ROWBATCH,
    output_type=service__msg__pb2._INTEGERRANGERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='milvus.proto.service.MilvusService.Search',
    index=11,
    containing_service=None,
    input_type=service__msg__pb2._QUERY,
    output_type=service__msg__pb2._QUERYRESULT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateIndex',
    full_name='milvus.proto.service.MilvusService.CreateIndex',
    index=12,
    containing_service=None,
    input_type=service__msg__pb2._INDEXPARAM,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeIndex',
    full_name='milvus.proto.service.MilvusService.DescribeIndex',
    index=13,
    containing_service=None,
    input_type=service__msg__pb2._DESCRIBEINDEXREQUEST,
    output_type=service__msg__pb2._DESCRIBEINDEXRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeIndexProgress',
    full_name='milvus.proto.service.MilvusService.DescribeIndexProgress',
    index=14,
    containing_service=None,
    input_type=service__msg__pb2._DESCRIBEINDEXPROGRESSREQUEST,
    output_type=service__msg__pb2._BOOLRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MILVUSSERVICE)

DESCRIPTOR.services_by_name['MilvusService'] = _MILVUSSERVICE

# @@protoc_insertion_point(module_scope)
